#
# spec file for package twm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           twm
Version:        1.0.12
Release:        2.4
Summary:        Tab Window Manager for the X Window System
License:        HPND
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        twm.desktop
Patch1:         twm-suse.diff
BuildRequires:  bison
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xt)
# This was part of the xorg-x11 package up to version 7.6
Provides:       windowmanager
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
twm is a window manager for the X Window System. It provides
titlebars, shaped windows, several forms of icon management,
user-defined macro functions, click-to-type and pointer-driven
keyboard focus, and user-specified key and pointer button bindings.

%prep
%autosetup -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install
install -m0644 -D %{SOURCE1} %{buildroot}%{_datadir}/xsessions/twm.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/twm.desktop

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README.md
%{_bindir}/twm
%{_datadir}/X11/twm/
%{_datadir}/xsessions/twm.desktop
%{_mandir}/man1/twm.1%{?ext_man}

%changelog
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Apr  2 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to 1.0.12
  * bugfix release
* Mon Jun 15 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to 1.0.11:
  * bugfix release
* Wed Mar  7 2018 mvetter@suse.com
- Update to 1.0.10:
  * Do not try to extend the font-pattern with a wild-card.
  * Add some const.
  * Adapt callers to ExpandFilename change.
  * autogen.sh: use exec instead of waiting for configure to finish
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
* Mon Aug  8 2016 eich@suse.com
- Adding generic windowmanager provides:
  Provides: windowmanager
  (boo#981663).
* Fri Apr 24 2015 sndirsch@suse.com
-  Update to version 1.0.9:
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Only use results from GetWindowProperty if it returned success
  * Remove custom version of system(3c) for Solaris
  * config: replace deprecated use of AC_OUTPUT with AC_CONFIG_FILES
  * Update manpage with the proper location of system.twmrc file
* Thu Feb  6 2014 sndirsch@suse.com
- fixed license to HPND in specfile
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.0.8:
  + Replace malloc(strlen()+1); strcpy(); pairs with strdup().
  + AddWindow: Use NULL instead of 0 for null pointer check.
  + Stop casting return values from malloc & calloc.
  + Stop casting pointers to (char *) when freeing them.
  + Delete trailing whitespace in non *.[ch] source files.
  + Make more functions static that aren't called from other
    files.
  + Assume C89 signal handlers, returning void.
  + Make some more previously global variables into file-scoped
    statics.
  + Remove unused global variable gotFirstSave.
  + Make various helper & callback functions private to session.c.
  + Convert remaining K&R function declarations to C89 style.
  + Use (void) to declare functions that take no arguments,
    instead of ().
  + Syntax error in recent twm commit.
  + Constification cleanup - fix dozens of gcc warnings.
  + Don't rely on the ability to set tab stops.
  + Fix SEGV if CreateColormapWindow() returns NULL.
  + Terminate execl() arguments with NULL instead of 0.
- Drop twm-sig11.diff, fixed upstream.
* Sun Apr 15 2012 dimstar@opensuse.org
- Update to version 1.0.7:
  + Replace most sprintf calls with snprintf
  + lex & yacc: only header file needs to be in BUILT_SOURCES
  + Bugs fixed: fdo#32696
- Changes from version 1.0.6:
  + Build system fixes.
- Add pkgconfig(xproto) BuildRequires: new upstream dependency.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split twm from xorg-x11. Initial version: 1.0.5.
